pub type PluginDynEntryPoint = PluginEntryPoint;Expand description
Type of the dyn entry point that foreign plugins export
(C++ CDYN_EXPORT AbiStableDynRef name_get_dyn(), Zig declareDynEntry).
pub type PluginDynEntryPoint = PluginEntryPoint;Type of the dyn entry point that foreign plugins export
(C++ CDYN_EXPORT AbiStableDynRef name_get_dyn(), Zig declareDynEntry).