pub unsafe fn unpack_fat_ptr<T: ?Sized>(ptr: AbiDynFatPtr) -> *const TExpand description
Unpack an ABI-stable fat pointer back to *const T.
Safety
ptr must have been created from a compatible *const T.
pub unsafe fn unpack_fat_ptr<T: ?Sized>(ptr: AbiDynFatPtr) -> *const TUnpack an ABI-stable fat pointer back to *const T.
ptr must have been created from a compatible *const T.