#[repr(C)]pub struct AbiStableDynRef {
pub object: AbiDynFatPtr,
pub retain: RetainFn,
pub release: ReleaseFn,
}Expand description
ABI-stable reference to a dyn trait object, with retain/release for safe reference counting across dynamic library boundaries.
Fields
object: AbiDynFatPtrretain: RetainFnrelease: ReleaseFnImplementations