pub type PluginEntryPoint = unsafe extern "C" fn() -> AbiStableDynRef;Expand description
Type of the entry point function that plugins must export.
pub type PluginEntryPoint = unsafe extern "C" fn() -> AbiStableDynRef;Type of the entry point function that plugins must export.