pub unsafe fn looks_like_plugin(path: &Path, entry_symbol: &[u8]) -> bool
Quick check: does the file look like a plugin with the given entry symbol?
Probes an arbitrary dynamic library for a specific exported symbol.